function md=tres(md,string)
%TRES - transfer results results to corresponding model fields. 
%
%    Usage: md=tres(md,string)
%
%    Example: md=tres(md,'diagnostic');

%check number of arguments

if strcmpi(string,'diagnostic'),
	if md.dim==2,
		if isfield(md.results.DiagnosticSolution,'VxAverage'),
			md.vx=PatchToVec(md.results.DiagnosticSolution.VxAverage);
		else
			md.vx=PatchToVec(md.results.DiagnosticSolution.Vx);
		end
		if isfield(md.results.DiagnosticSolution,'VyAverage'),
			md.vy=PatchToVec(md.results.DiagnosticSolution.VyAverage);
		else
			md.vy=PatchToVec(md.results.DiagnosticSolution.Vy);
		end
	else 
		md.vx=PatchToVec(md.results.DiagnosticSolution.Vx);
		md.vy=PatchToVec(md.results.DiagnosticSolution.Vy);
		if isfield(md.results.DiagnosticSolution,'Vz'),
			md.vz=PatchToVec(md.results.DiagnosticSolution.Vz);
		else
			md.vz=zeros(md.numberofgrids,1);
		end
	end
	md.vel=PatchToVec(md.results.DiagnosticSolution.Vel);

	if isfield(md.results.DiagnosticSolution,'Pressure'),
		md.pressure=PatchToVec(md.results.DiagnosticSolution.Pressure);
	end
	if md.numrifts,
		if isfield(md.results.DiagnosticSolution,'riftproperties'),
			md.riftproperties=md.results.DiagnosticSolution.riftproperties;
		end
	end
	if md.control_analysis==1,
		for control_type=md.control_type
			md.(EnumToModelField(control_type))=PatchToVec(md.results.DiagnosticSolution.(EnumToString(control_type)));
		end
	end
elseif strcmpi(string,'dakota'),
	md.dakotaresults=md.results.dakota;

elseif strcmpi(string,'transient'),
	results=md.results.Transient2DSolution;
	results2.Vel=NaN;
	count=1;
	for i=1:length(results),
		if ~isempty(md.results.Transient2DSolution(i).Vel),
			results2(count).Vel=PatchToVec(md.results.Transient2DSolution(i).Vel);
			results2(count).Surface=PatchToVec(md.results.Transient2DSolution(i).Surface);
			results2(count).Thickness=PatchToVec(md.results.Transient2DSolution(i).Thickness);
			results2(count).Bed=PatchToVec(md.results.Transient2DSolution(i).Bed);
			results2(count).Vx=PatchToVec(md.results.Transient2DSolution(i).Vx);
			results2(count).Vy=PatchToVec(md.results.Transient2DSolution(i).Vy);
			results2(count).time=md.results.Transient2DSolution(i).time;
			results2(count).step=md.results.Transient2DSolution(i).step;
			if md.gl_migration,
				results2(count).ElementOnIceShelf=PatchToVec(md.results.Transient2DSolution(i).ElementOnIceShelf);
			end
			count=count+1;
		end
	end
	md.results.Transient2DSolution=results2;
	clear results,results2;
elseif strcmpi(string,'steadystate'),
	md.vx=PatchToVec(md.results.SteadystateSolution.Vx);
	md.vy=PatchToVec(md.results.SteadystateSolution.Vy);
	if isfield(md.results.SteadystateSolution,'Vz'),
		md.vz=PatchToVec(md.results.SteadystateSolution.Vz);
	end

	md.vel=PatchToVec(md.results.SteadystateSolution.Vel);
	md.pressure=PatchToVec(md.results.SteadystateSolution.Pressure);
	md.temperature=PatchToVec(md.results.SteadystateSolution.Temperature);
	md.melting_rate=PatchToVec(md.results.SteadystateSolution.MeltingRate);
	
	if md.control_analysis==1,
		if control_type==md.control_type
			md.(EnumToModelField(control_type))=PatchToVec(md.results.DiagnosticSolution.(EnumToString(control_type)));
		end
	end

elseif strcmpi(string,'thermal'),
	md.temperature=PatchToVec(md.results.ThermalSolution.Temperature);
	md.melting_rate=PatchToVec(md.results.ThermalSolution.MeltingRate);
else 
	error(['tres error message: analysis ' string ' not supported yet!']);
end
